@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 
 """
 Copyright (c) 2006-2019 sqlmap developers (http://sqlmap.org/)
@@ -9,9 +9,6 @@ from lib.core.exception import SqlmapUnsupportedFeatureException
 from plugins.generic.connector import Connector as GenericConnector
 
 class Connector(GenericConnector):
-    def __init__(self):
-        GenericConnector.__init__(self)
-
     def connect(self):
         errMsg = "on SAP MaxDB it is not (currently) possible to establish a "
         errMsg += "direct connection"
